@@ -86,15 +86,15 @@
       members: [],
       networks: {},
       flavors: {},
-      listenerProtocols: ['HTTP', 'TCP', 'TERMINATED_HTTPS', 'HTTPS'],
+      listenerProtocols: ['HTTP', 'TCP', 'TERMINATED_HTTPS', 'HTTPS', 'UDP'],
       l7policyActions: ['REJECT', 'REDIRECT_TO_URL', 'REDIRECT_TO_POOL'],
       l7ruleTypes: ['HOST_NAME', 'PATH', 'FILE_TYPE', 'HEADER', 'COOKIE'],
       l7ruleCompareTypes: ['REGEX', 'EQUAL_TO', 'STARTS_WITH', 'ENDS_WITH', 'CONTAINS'],
       l7ruleFileTypeCompareTypes: ['REGEX', 'EQUAL_TO'],
-      poolProtocols: ['HTTP', 'HTTPS', 'PROXY', 'TCP'],
+      poolProtocols: ['HTTP', 'HTTPS', 'PROXY', 'TCP', 'UDP'],
       methods: ['LEAST_CONNECTIONS', 'ROUND_ROBIN', 'SOURCE_IP'],
       types: ['SOURCE_IP', 'HTTP_COOKIE', 'APP_COOKIE'],
-      monitorTypes: ['HTTP', 'HTTPS', 'PING', 'TCP', 'TLS-HELLO'],
+      monitorTypes: ['HTTP', 'HTTPS', 'PING', 'TCP', 'TLS-HELLO', 'UDP-CONNECT'],
       monitorMethods: ['GET', 'HEAD', 'POST', 'PUT', 'DELETE',
                        'TRACE', 'OPTIONS', 'PATCH', 'CONNECT'],
       certificates: [],
@@ -574,7 +574,7 @@
       }
 
       // Only include necessary monitor properties
-      if (finalSpec.monitor.type !== 'HTTP' && finalSpec.monitor.type !== 'HTTPS') {
+      if (finalSpec.monitor.type !== 'HTTP') {
         delete finalSpec.monitor.http_method;
         delete finalSpec.monitor.expected_codes;
         delete finalSpec.monitor.url_path;
@@ -886,7 +886,6 @@
         });
         return 'certificate' in container.refs && 'private_key' in container.refs;
       });
-      var certHrefs = [];
       var secrets = {};
       results[1].data.items.forEach(function addSecret(secret) {
         secrets[secret.secret_ref] = secret;
@@ -898,23 +897,7 @@
           name: secret.name || secret.secret_ref.split('/').reverse()[0],
           expiration: secret.expiration
         });
-        certHrefs.push(secret.secret_ref);
       });
-      // Octavia now supports pkcs12 bundles which are stored as secrets.
-      // If the secret hasn't already been loaded, add it to the list.
-      for (var key in secrets) {
-        if (secrets[key].secret_type !== "opaque") {continue;}
-        var cert = {
-          id: key,
-          name: secrets[key].name || key,
-          expiration: secrets[key].expiration
-        };
-        if (certHrefs.indexOf(key) === -1) {
-          certificates.push(cert);
-          certHrefs.push(key);
-        }
-      }
-
       push.apply(model.certificates, certificates);
     }
 
