@@ -342,15 +342,11 @@
               secret_ref: 'certificate1'
             }, {
               expiration: '2016-03-28T21:10:45.417835',
-              secret_ref: 'certificate2',
-              secret_type: 'opaque'
+              secret_ref: 'certificate2'
             }, {
               secret_ref: 'privatekey1'
             }, {
               secret_ref: 'privatekey2'
-            }, {
-              secret_ref: 'pkcs12',
-              secret_type: 'opaque'
             }
           ];
 
@@ -469,7 +465,8 @@
       });
 
       it('has array of listener protocols', function() {
-        expect(model.listenerProtocols).toEqual(['HTTP', 'TCP', 'TERMINATED_HTTPS', 'HTTPS']);
+        expect(model.listenerProtocols).toEqual(['HTTP', 'TCP', 'TERMINATED_HTTPS', 'HTTPS',
+          'UDP']);
       });
 
       it('has array of pool lb_algorithms', function() {
@@ -481,7 +478,8 @@
       });
 
       it('has array of monitor types', function() {
-        expect(model.monitorTypes).toEqual(['HTTP', 'HTTPS', 'PING', 'TCP', 'TLS-HELLO']);
+        expect(model.monitorTypes).toEqual(['HTTP', 'HTTPS', 'PING', 'TCP', 'TLS-HELLO',
+          'UDP-CONNECT']);
       });
 
       it('has array of monitor http_methods', function() {
@@ -516,7 +514,7 @@
         expect(model.networks).toEqual(mockNetworks);
         expect(model.flavors).toEqual(mockFlavors);
         expect(model.members.length).toBe(2);
-        expect(model.certificates.length).toBe(3);
+        expect(model.certificates.length).toBe(2);
         expect(model.listenerPorts.length).toBe(0);
         expect(model.spec).toBeDefined();
         expect(model.spec.loadbalancer_id).toBeUndefined();
@@ -554,7 +552,7 @@
         expect(model.initialized).toBe(true);
         expect(model.subnets.length).toBe(2);
         expect(model.members.length).toBe(2);
-        expect(model.certificates.length).toBe(3);
+        expect(model.certificates.length).toBe(2);
         expect(model.listenerPorts.length).toBe(3);
         expect(model.spec).toBeDefined();
         expect(model.spec.loadbalancer_id).toBe('1234');
@@ -837,7 +835,7 @@
       });
 
       it('should initialize listener protocols', function() {
-        expect(model.listenerProtocols.length).toBe(4);
+        expect(model.listenerProtocols.length).toBe(5);
         expect(model.listenerProtocols.indexOf('TERMINATED_HTTPS')).toBe(2);
       });
     });
@@ -888,7 +886,7 @@
       });
 
       it('should initialize listener protocols', function() {
-        expect(model.listenerProtocols.length).toBe(3);
+        expect(model.listenerProtocols.length).toBe(4);
         expect(model.listenerProtocols.indexOf('TERMINATED_HTTPS')).toBe(-1);
       });
     });
@@ -1234,7 +1232,7 @@
       });
 
       it('should initialize certificates', function() {
-        expect(model.certificates.length).toBe(3);
+        expect(model.certificates.length).toBe(2);
         expect(model.spec.certificates.length).toBe(1);
         expect(model.spec.certificates[0].id).toBe('container2');
       });
